@@ -15,16 +15,16 @@ class SMR:
         self._session = aiohttp.ClientSession(
             loop=loop
         )
-        self._url = "https://some-random-api.ml"
+        self.__url = "https://some-random-api.ml"
 
 
-    async def get_point(self, category: Optional[str], name: Optional[str], path: Optional[str]) -> str:
+    async def get_point(self, category: str=None, name: str=None, path: str=None):
         """
         Examples:
 
         await smr_async.SMR().get_point(category="canvas", path="?avatar='avatar_url'..."
         """
-        async with self._session.get(f'{self._url}/{category}/{name}' + path) as res:
+        async with self._session.get(f'{self.__url}/{name}' if None in (category, path) else f'{self.__url}/{category}/{name}' if path == None else f'{self.__url}/{category}/{name}' + path) as res:
             if res.ok:
                 try:
                     a = await res.json()
