@@ -1,5 +1,5 @@
 import requests
-from typing import Optional
+from typing import Literal
 
 from .errors import *
 
@@ -8,10 +8,10 @@ class SMR_client:
 
     def __init__(self):
         self._session = requests
-        self._url = "https://some-random-api.ml"
+        self.__url = "https://some-random-api.ml"
 
-    def get_point(self, category: Optional[str], name: Optional[str], path: Optional[str]) -> str:
-        request = self._session.get(f'{self._url}/{category}/{name}' + path)
+    def get_point(self, category: str=None, name: str=None, path: str=None):
+        request = self._session.get(f'{self.__url}/{name}' if None in (category, path) else f'{self.__url}/{category}/{name}' if path == None else f'{self.__url}/{category}/{name}' + path)
         if request.ok:
             try:
                 data = request.json()
